==> ogre-next-2.3.3-1-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/struct_ogre_1_1_vulkan_device.js <==
var struct_ogre_1_1_vulkan_device =
[
    [ "SelectedQueue", "struct_ogre_1_1_vulkan_device_1_1_selected_queue.html", "struct_ogre_1_1_vulkan_device_1_1_selected_queue" ],
    [ "VulkanDevice", "struct_ogre_1_1_vulkan_device.html#a99a35ff646d43bb6b35d192074e877e6", null ],
    [ "VulkanDevice", "struct_ogre_1_1_vulkan_device.html#aeadd599baa942564b959b53910ee47ad", null ],
    [ "~VulkanDevice", "struct_ogre_1_1_vulkan_device.html#af497fbe8f23d8a1def3ba2a111db3214", null ],
    [ "addExternalInstanceExtensions", "struct_ogre_1_1_vulkan_device.html#a08360b6163664b233a32b7b552bc871a", null ],
    [ "commitAndNextCommandBuffer", "struct_ogre_1_1_vulkan_device.html#aba601df6a5751a44c1b4b5ff63754d2d", null ],
    [ "createDevice", "struct_ogre_1_1_vulkan_device.html#a85acdf7f991b9f09a6cbde24bb4beb0c", null ],
    [ "createInstance", "struct_ogre_1_1_vulkan_device.html#a456458f51a1947894637a78bcccd5aca", null ],
    [ "destroyQueues", "struct_ogre_1_1_vulkan_device.html#a55ecf3d331abc31e467ca32ce386490a", null ],
    [ "fillDeviceFeatures", "struct_ogre_1_1_vulkan_device.html#a168c0d0ca21a2e3df6fa7abbfa594a5d", null ],
    [ "fillQueueCreationInfo", "struct_ogre_1_1_vulkan_device.html#a857f4d05cc191573c3a56adf69581c07", null ],
    [ "findComputeQueue", "struct_ogre_1_1_vulkan_device.html#a273b42eb4822c8b473698a7b71f4ebf8", null ],
    [ "findGraphicsQueue", "struct_ogre_1_1_vulkan_device.html#ab3d60c37eccfa0bf7963344e3ef8e5db", null ],
    [ "findTransferQueue", "struct_ogre_1_1_vulkan_device.html#a97871fbfe49781ce5e18e1d2e833f523", null ],
    [ "hasDeviceExtension", "struct_ogre_1_1_vulkan_device.html#a9fbbb869e1ee3059a20fd44e46b8688a", null ],
    [ "hasInstanceExtension", "struct_ogre_1_1_vulkan_device.html#ad297c3cb0e91a9bcbe4a1232901dad94", null ],
    [ "initQueues", "struct_ogre_1_1_vulkan_device.html#a20ba196505a0e5aaf49fc64b1c15d994", null ],
    [ "stall", "struct_ogre_1_1_vulkan_device.html#a27424f4bc1eae4ed2913984e673bd0a2", null ],
    [ "mComputeQueues", "struct_ogre_1_1_vulkan_device.html#ab4c87165ec889ff2051fbc33ba364043", null ],
    [ "mDevice", "struct_ogre_1_1_vulkan_device.html#a60257e86a9b5d30dfdd46a614d5db43a", null ],
    [ "mDeviceExtensions", "struct_ogre_1_1_vulkan_device.html#a88a1db69a47feac6a3ed8aff46e758cc", null ],
    [ "mDeviceFeatures", "struct_ogre_1_1_vulkan_device.html#a7ef4793068b7a83eda78aee406f4decf", null ],
    [ "mDeviceMemoryProperties", "struct_ogre_1_1_vulkan_device.html#ae174a7cb061e258cb27230f8114b7ee3", null ],
    [ "mDeviceProperties", "struct_ogre_1_1_vulkan_device.html#a5aa808400dbddb71ba3da47b93d276dc", null ],
    [ "mGraphicsQueue", "struct_ogre_1_1_vulkan_device.html#a3fca8e0da8c1f51138f975f83fde3c6e", null ],
    [ "mInstance", "struct_ogre_1_1_vulkan_device.html#ad03bde234046f81d5840f88bda6f8193", null ],
    [ "mIsExternal", "struct_ogre_1_1_vulkan_device.html#ae748f30c1f0bc89c9b376873f68a7582", null ],
    [ "mPhysicalDevice", "struct_ogre_1_1_vulkan_device.html#a9a5164e2fdbec15196ad2809148e00ff", null ],
    [ "mPresentQueue", "struct_ogre_1_1_vulkan_device.html#a41b96fdf17d1bd57d73f0037aaebfe04", null ],
    [ "mQueueProps", "struct_ogre_1_1_vulkan_device.html#a4abeb2705259c215a6a19b45e1ea309d", null ],
    [ "mRenderSystem", "struct_ogre_1_1_vulkan_device.html#a85ef8bb90f196ed4d99daac696a377ac", null ],
    [ "mSupportedStages", "struct_ogre_1_1_vulkan_device.html#a166e81608d5d85d33c457a6f0696dd52", null ],
    [ "mTransferQueues", "struct_ogre_1_1_vulkan_device.html#ad1b8cad0bec0d64eae84b3e6d20e9cdc", null ],
    [ "mVaoManager", "struct_ogre_1_1_vulkan_device.html#a0c5f0db9b1549898cba45c34800b3ef0", null ]
];

==> ogre-next-3.0.0-2-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/struct_ogre_1_1_vulkan_device.js <==
var struct_ogre_1_1_vulkan_device =
[
    [ "ExtraVkFeatures", "struct_ogre_1_1_vulkan_device_1_1_extra_vk_features.html", "struct_ogre_1_1_vulkan_device_1_1_extra_vk_features" ],
    [ "SelectedQueue", "struct_ogre_1_1_vulkan_device_1_1_selected_queue.html", "struct_ogre_1_1_vulkan_device_1_1_selected_queue" ],
    [ "VulkanDevice", "struct_ogre_1_1_vulkan_device.html#a99a35ff646d43bb6b35d192074e877e6", null ],
    [ "VulkanDevice", "struct_ogre_1_1_vulkan_device.html#aeadd599baa942564b959b53910ee47ad", null ],
    [ "~VulkanDevice", "struct_ogre_1_1_vulkan_device.html#af497fbe8f23d8a1def3ba2a111db3214", null ],
    [ "addExternalInstanceExtensions", "struct_ogre_1_1_vulkan_device.html#a08360b6163664b233a32b7b552bc871a", null ],
    [ "commitAndNextCommandBuffer", "struct_ogre_1_1_vulkan_device.html#aba601df6a5751a44c1b4b5ff63754d2d", null ],
    [ "createDevice", "struct_ogre_1_1_vulkan_device.html#a85acdf7f991b9f09a6cbde24bb4beb0c", null ],
    [ "createInstance", "struct_ogre_1_1_vulkan_device.html#a456458f51a1947894637a78bcccd5aca", null ],
    [ "destroyQueues", "struct_ogre_1_1_vulkan_device.html#a55ecf3d331abc31e467ca32ce386490a", null ],
    [ "fillDeviceFeatures", "struct_ogre_1_1_vulkan_device.html#a168c0d0ca21a2e3df6fa7abbfa594a5d", null ],
    [ "fillQueueCreationInfo", "struct_ogre_1_1_vulkan_device.html#a857f4d05cc191573c3a56adf69581c07", null ],
    [ "findComputeQueue", "struct_ogre_1_1_vulkan_device.html#a273b42eb4822c8b473698a7b71f4ebf8", null ],
    [ "findGraphicsQueue", "struct_ogre_1_1_vulkan_device.html#ab3d60c37eccfa0bf7963344e3ef8e5db", null ],
    [ "findTransferQueue", "struct_ogre_1_1_vulkan_device.html#a97871fbfe49781ce5e18e1d2e833f523", null ],
    [ "hasDeviceExtension", "struct_ogre_1_1_vulkan_device.html#a9fbbb869e1ee3059a20fd44e46b8688a", null ],
    [ "hasInstanceExtension", "struct_ogre_1_1_vulkan_device.html#ad297c3cb0e91a9bcbe4a1232901dad94", null ],
    [ "initQueues", "struct_ogre_1_1_vulkan_device.html#a0369aa624f9b0d76521077b89699f49f", null ],
    [ "stall", "struct_ogre_1_1_vulkan_device.html#a9052e6d3cb9531fcea410cdce25e16f9", null ],
    [ "mComputeQueues", "struct_ogre_1_1_vulkan_device.html#ab4c87165ec889ff2051fbc33ba364043", null ],
    [ "mDevice", "struct_ogre_1_1_vulkan_device.html#a60257e86a9b5d30dfdd46a614d5db43a", null ],
    [ "mDeviceExtensions", "struct_ogre_1_1_vulkan_device.html#a88a1db69a47feac6a3ed8aff46e758cc", null ],
    [ "mDeviceExtraFeatures", "struct_ogre_1_1_vulkan_device.html#a65f8a4ee1a653f4d599caeda0fd18e8d", null ],
    [ "mDeviceFeatures", "struct_ogre_1_1_vulkan_device.html#a7ef4793068b7a83eda78aee406f4decf", null ],
    [ "mDeviceMemoryProperties", "struct_ogre_1_1_vulkan_device.html#ae174a7cb061e258cb27230f8114b7ee3", null ],
    [ "mDeviceProperties", "struct_ogre_1_1_vulkan_device.html#a5aa808400dbddb71ba3da47b93d276dc", null ],
    [ "mGraphicsQueue", "struct_ogre_1_1_vulkan_device.html#a3fca8e0da8c1f51138f975f83fde3c6e", null ],
    [ "mInstance", "struct_ogre_1_1_vulkan_device.html#ad03bde234046f81d5840f88bda6f8193", null ],
    [ "mIsExternal", "struct_ogre_1_1_vulkan_device.html#ae748f30c1f0bc89c9b376873f68a7582", null ],
    [ "mPhysicalDevice", "struct_ogre_1_1_vulkan_device.html#a9a5164e2fdbec15196ad2809148e00ff", null ],
    [ "mPresentQueue", "struct_ogre_1_1_vulkan_device.html#a41b96fdf17d1bd57d73f0037aaebfe04", null ],
    [ "mQueueProps", "struct_ogre_1_1_vulkan_device.html#a4abeb2705259c215a6a19b45e1ea309d", null ],
    [ "mRenderSystem", "struct_ogre_1_1_vulkan_device.html#a85ef8bb90f196ed4d99daac696a377ac", null ],
    [ "mSupportedStages", "struct_ogre_1_1_vulkan_device.html#a166e81608d5d85d33c457a6f0696dd52", null ],
    [ "mTransferQueues", "struct_ogre_1_1_vulkan_device.html#ad1b8cad0bec0d64eae84b3e6d20e9cdc", null ],
    [ "mVaoManager", "struct_ogre_1_1_vulkan_device.html#a0c5f0db9b1549898cba45c34800b3ef0", null ]
];
